translate.storage.xpi.ZipFileCatcher

Package translate :: Package storage :: Module xpi :: Class ZipFileCatcher |
[hide private]
[frames] | no frames]

# Class ZipFileCatcher

source code

a ZipFile that calls any methods its instructed to before closing (useful for catching stream output)

Instance Methods | [hide private]
__init__(self, *args, **kwargs) initialize the ZipFileCatcher | source code
addcatcher(self, pendingsave) remember to call the given method before closing | source code
close(self) close the stream, remembering to call any addcatcher methods first | source code
overwritestr(self, zinfo_or_arcname, bytes) writes the string into the archive, overwriting the file if it exists... | source code
Inherited from `misc.zipfileext.ZipFileExt`: `delete`, `writeendrec` Inherited from `zipfile.ZipFile`: `__del__`, `extract`, `extractall`, `getinfo`, `infolist`, `namelist`, `open`, `printdir`, `read`, `setpassword`, `testzip`, `write`, `writestr` Inherited from `zipfile.ZipFile` (private): `_GetContents`, `_RealGetContents`, `_extract_member`, `_writecheck` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `zipfile.ZipFile`: `fp`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
initialize the ZipFileCatcher Overrides: object.__init__

### close(self) | source code
close the stream, remembering to call any addcatcher methods first Overrides: zipfile.ZipFile.close